/**
 * Copyright (c) 2011, Qulice.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 1) Redistributions of source code must retain the above
 * copyright notice, this list of conditions and the following
 * disclaimer. 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution. 3) Neither the name of the Qulice.com nor
 * the names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.qulice.maven;

import java.util.ArrayList;
import java.util.List;
import java.util.Properties;
import org.apache.maven.execution.MavenSession;
import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MavenPluginManager;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugin.logging.Log;
import org.apache.maven.project.MavenProject;
import org.codehaus.plexus.context.Context;
import org.codehaus.plexus.context.ContextException;
import org.codehaus.plexus.personality.plexus.lifecycle.phase.Contextualizable;

/**
 * Environment, passed from MOJO to validator.
 *
 * @author Yegor Bugayenko (yegor@qulice.com)
 * @version $Id: Environment.java 56 2011-09-29 13:48:23Z guard $
 */
public final class Environment {

    /**
     * Maven project.
     */
    private MavenProject project;

    /**
     * Plexus context.
     */
    private Context context;

    /**
     * Log.
     */
    private Log log;

    /**
     * Plugin configuration.
     */
    private final Properties properties = new Properties();

    /**
     * MOJO executor.
     */
    private MojoExecutor mojoExecutor;

    /**
     * Set Maven Project (used mostly for unit testing).
     * @param proj The project to set
     */
    public void setProject(final MavenProject proj) {
        this.project = proj;
    }

    /**
     * Set context.
     * @param ctx The context to set
     */
    public void setContext(final Context ctx) {
        this.context = ctx;
    }

    /**
     * Set log.
     * @param mlog The Maven log
     */
    public void setLog(final Log mlog) {
        this.log = mlog;
    }

    /**
     * Set executor.
     * @param exec The executor
     */
    public void setMojoExecutor(final MojoExecutor exec) {
        this.mojoExecutor = exec;
    }

    /**
     * Set property.
     * @param name Its name
     * @param value Its value
     */
    public void setProperty(final String name, final String value) {
        this.properties.setProperty(name, value);
    }

    /**
     * Get project.
     * @return The project
     */
    public MavenProject project() {
        return this.project;
    }

    /**
     * Get properties.
     * @return The properties
     */
    public Properties properties() {
        return this.properties;
    }

    /**
     * Get context.
     * @return The context
     */
    public Context context() {
        return this.context;
    }

    /**
     * Get log.
     * @return The log
     */
    public Log log() {
        return this.log;
    }

    /**
     * Get plugin configuration properties.
     * @return The props
     */
    public Properties config() {
        return this.properties;
    }

    /**
     * Get MOJO executor.
     * @return The executor
     */
    public MojoExecutor executor() {
        return this.mojoExecutor;
    }

}
